package com.ljump.sdk.common;

import com.ljump.sdk.common.classes.response.ClassType;
import com.ljump.sdk.common.pages.response.PageType;
import com.ljump.sdk.common.util.LJumpCommonUtil;
import com.ljump.sdk.server.common.LJumpStatusEnum;
import com.ljump.sdk.server.connection.ILJumpEditableResource;

/**
 * Abstract tester for testing resource level operations
 * 
 * <br/><br/>
 * <table border="1">
 * 	<tr>
 * 	<th width="10%">Date (DD/MM/YYYY)</th>
 * 	<th width="10%">Author</th>
 * 	<th align="left">Description</th>
 * 	</tr>
 * 
 * 	<tr>
 * 	<td>Sep 21, 2010</td>
 * 	<td>Eclipse Inertia</td>
 * 	<td>Initial Creation</td>
 * 	</tr>
 * </table>
 */
public abstract class TestLJumpResourceEdit extends LJumpBaseTestCase {

	protected void checkSaveOnServer(String addedLine) throws Exception {
		
		// Store the last modified date
		ILJumpEditableResource<?> resource = retrieveResource();
		Object jaxbObject = resource.getJAXBModel();
		boolean isClass = jaxbObject instanceof ClassType;	
		ClassType clazz = isClass ? (ClassType)jaxbObject : null;
		PageType page = isClass ? null : (PageType)jaxbObject;
		
		long originalModifiedDate = isClass ? clazz.getDateModified() : page.getDateModified();
		String originalCode = isClass ? clazz.getCode() : page.getCode();
		if (isClass) {
			clazz.setCode (LJumpCommonUtil.concat(addedLine, clazz.getCode()));
		}
		else {
			page.setCode (LJumpCommonUtil.concat(addedLine, page.getCode()));
		}
				
		// Save the resource on server
		LJumpStatusEnum saveStatus = resource.saveOnServer();
		assertEquals(LJumpStatusEnum.SUCCESS, saveStatus);
		
		// Fetch again, and make sure its updated		
		resource = retrieveResource();
		jaxbObject = resource.getJAXBModel();			
		clazz = isClass ? (ClassType)jaxbObject : null;
		page = isClass ? null : (PageType)jaxbObject;
		
		assertTrue((isClass ? clazz.getDateModified() : page.getDateModified()) > originalModifiedDate);
		assertTrue((isClass ? clazz.getCode() : page.getCode()).startsWith(addedLine));
		
		// Revert the original code
		if (isClass) {
			clazz.setCode (originalCode);
		}
		else {
			page.setCode (originalCode);
		}

		saveStatus = resource.saveOnServer();
		assertEquals(LJumpStatusEnum.SUCCESS, saveStatus);
	}

	protected void checkFetchFromServer() throws Exception {
		ILJumpEditableResource<?> resource = retrieveResource();
		assertEquals (LJumpStatusEnum.SUCCESS, resource.fetchFromServer());
	}
	
	
	protected void checkDeleteFromServer () throws Exception {
		ILJumpEditableResource<?> resource = retriveNewResource();
		assertEquals (LJumpStatusEnum.CREATE_SUCCEEDED, resource.saveOnServer());
		
		assertEquals (LJumpStatusEnum.SUCCESS, resource.deleteFromServer());
	}
	
	
	protected abstract ILJumpEditableResource<?> retrieveResource() throws Exception;
	
	protected abstract ILJumpEditableResource<?> retriveNewResource() throws Exception;
}
