package com.ljump.sdk.server.tests;


import org.junit.Test;

import com.ljump.sdk.common.TestLJumpResourceEdit;
import com.ljump.sdk.common.classes.response.ClassType;
import com.ljump.sdk.common.classes.response.ObjectFactory;
import com.ljump.sdk.server.connection.ILJumpEditableResource;
import com.ljump.sdk.server.connection.ILJumpResourceMetadata;
import com.ljump.sdk.server.connection.impl.LJumpClassResource;
import com.ljump.sdk.server.connection.impl.LJumpResourceMetadata;
import com.ljump.sdk.server.connection.impl.LJumpServerConnection;

/**
 * Used for testing class edit operations.  For example:
 * <ol>
 * 	<li>saveOnServer</li>
 * 	<li>delete</li>
 * 	<li>fetchFromServer</li>
 * </ol>
 * 
 * <br/><br/>
 * <table border="1">
 * 	<tr>
 * 	<th width="10%">Date (DD/MM/YYYY)</th>
 * 	<th width="10%">Author</th>
 * 	<th align="left">Description</th>
 * 	</tr>
 * 
 * 	<tr>
 * 	<td>Sep 20, 2010</td>
 * 	<td>Eclipse Inertia</td>
 * 	<td>Initial Creation</td>
 * 	</tr>
 * </table>
 */
public class TestLJumpClassEdit extends TestLJumpResourceEdit {

	@Test
    public void testSaveOnServer() throws Exception {
		checkSaveOnServer ("// Comment added\n");
    }
	

	@Test
    public void testFetchFromServer() throws Exception {
		checkFetchFromServer ();
    }
	
	
	@Test
    public void testDeleteFromServer() throws Exception {
		checkDeleteFromServer ();
    }
	
	
	protected ILJumpEditableResource<?> retrieveResource() throws Exception {
		return createConnection().fetchClasses().getModel()[0];
		
	}


	@Override
	protected ILJumpEditableResource<?> retriveNewResource() throws Exception {
		
		ClassType clazz = new ObjectFactory().createClassType();
		ILJumpResourceMetadata metadata = new LJumpResourceMetadata(true, 0);
		ILJumpEditableResource<ClassType> resource = new LJumpClassResource((LJumpServerConnection)createConnection(), clazz, metadata); 
		
		clazz.setName("CustomClass");
		clazz.setPackageName("application");
		clazz.setCode("public class CustomClass{}");
		return resource;
	}
}
